pm4py.algo.organizational\_mining.roles.variants package
========================================================

Submodules
----------

pm4py.algo.organizational\_mining.roles.variants.log module
-----------------------------------------------------------

.. automodule:: pm4py.algo.organizational_mining.roles.variants.log
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.organizational\_mining.roles.variants.pandas module
--------------------------------------------------------------

.. automodule:: pm4py.algo.organizational_mining.roles.variants.pandas
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.organizational_mining.roles.variants
   :members:
   :undoc-members:
   :show-inheritance:
